..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

============================= ========================== ======================= 
                    base case              greedy method             stack frame
          dynamic programming                  recursion
                      fractal             recursive call
============================= ========================== ======================= 

